package com.ruoyi.warehouse.service;

import java.util.List;
import com.ruoyi.warehouse.domain.StockCheckRecord;

public interface IStockCheckRecordService
{
    public List<StockCheckRecord> selectStockCheckRecordList(StockCheckRecord stockCheckRecord);
    public StockCheckRecord selectStockCheckRecordById(Long id);
    public boolean checkCheckNoUnique(StockCheckRecord stockCheckRecord);
    public int insertStockCheckRecord(StockCheckRecord stockCheckRecord);
    public int updateStockCheckRecord(StockCheckRecord stockCheckRecord);
    public int deleteStockCheckRecordByIds(Long[] ids);
    public int confirmStockCheckRecord(Long id, String username);
}
